@@ -1,28 +1,29 @@
-from chex import dataclass
-from typing import Optional, Union, Callable
-from multipledispatch import dispatch
+from typing import Callable, Optional, Union
+
 import jax.numpy as jnp
+from chex import dataclass
+from multipledispatch import dispatch
 from tensorflow_probability.substrates.jax import distributions as tfd
 
 
 @dataclass
 class Likelihood:
-    name: Optional[str] = 'Likelihood'
+    name: Optional[str] = "Likelihood"
 
 
 @dataclass
 class Gaussian:
-    name: Optional[str] = 'Gaussian'
+    name: Optional[str] = "Gaussian"
 
 
 @dispatch(Gaussian)
 def initialise(likelihood: Gaussian) -> dict:
-    return {'obs_noise': jnp.array([1.0])}
+    return {"obs_noise": jnp.array([1.0])}
 
 
 @dataclass
 class Bernoulli:
-    name: Optional[str] = 'Bernoulli'
+    name: Optional[str] = "Bernoulli"
 
 
 @dispatch(Bernoulli)
@@ -34,20 +35,27 @@ def initialise(likelihood: Bernoulli) -> dict:
 def link_function(likelihood: Bernoulli):
     return tfd.ProbitBernoulli
 
+
 @dispatch(Bernoulli)
 def predictive_moments(likelihood: Bernoulli) -> Callable:
     link = link_function(likelihood)
+
     def moments(mean: jnp.DeviceArray, variance: jnp.DeviceArray) -> tfd.Distribution:
         rv = link(mean / jnp.sqrt(1 + variance))
         return rv
-    return moments
 
+    return moments
 
 
 @dataclass
 class Poisson:
-    name: Optional[str] = 'Poisson'
+    name: Optional[str] = "Poisson"
+
+
+@dispatch(Poisson)
+def initialise(likelihood: Poisson) -> dict:
+    return {}
 
 
 NonConjugateLikelihoods = (Bernoulli, Poisson)
-NonConjugateLikelihoodType = Union[Bernoulli, Poisson]
\ No newline at end of file
+NonConjugateLikelihoodType = Union[Bernoulli, Poisson]
