@@ -1,13 +1,16 @@
 from typing import Optional
+
 import jax.numpy as jnp
 from chex import dataclass
-from .types import Array
 from multipledispatch import dispatch
 
+from .types import Array
+
 
 @dataclass
 class MeanFunction:
-    name: Optional[str] = 'Mean Function'
+    output_dim: Optional[int] = 1
+    name: Optional[str] = "Mean Function"
 
     def __call__(self, x: Array) -> Array:
         raise NotImplementedError
@@ -15,12 +18,14 @@ class MeanFunction:
 
 @dataclass
 class Zero(MeanFunction):
-    name: Optional[str] = 'Zero mean'
+    output_dim: Optional[int] = 1
+    name: Optional[str] = "Zero mean"
 
     def __call__(self, x: Array) -> Array:
-        return jnp.zeros_like(x)
+        out_shape = (x.shape[0], self.output_dim)
+        return jnp.zeros(shape = out_shape)
 
 
 @dispatch(Zero)
 def initialise(meanf: Zero) -> dict:
-    return {}
\ No newline at end of file
+    return {}
